@@ -1,11 +1,7 @@
 jQuery(document).ready(function($) {
-    var editables = $('.editable');
 
-    editables.on('dblclick', function(event) {
-        event.preventDefault();
-
-        var el = $(this),
-            body = $('body'),
+    var triggerEditor = function(el) {
+        var body = $('body'),
             html = el.html(),
             el_id = el.attr('id'),
             tag = 'textarea',
@@ -61,7 +57,7 @@ jQuery(document).ready(function($) {
                 $.getScript(document._front_edit.static_root+'wymeditor/jquery.wymeditor.min.js', function(){
                     target.addClass('front-edit-wym');
                     var base_path = document._front_edit.static_root+'wymeditor/';
-                    $('#edit-' + el_id).wymeditor({
+                    var editor_options = $.extend({
                         updateSelector: "input:submit",
                         updateEvent: "click",
                         logoHtml: '',
@@ -76,11 +72,14 @@ jQuery(document).ready(function($) {
                         wymPath: base_path + 'jquery.wymeditor.min.js',
                         skinPath: document._front_edit.static_root + 'wym/django/'
 
-                    });
+                    }, document._front_edit.editor_options);
+                    $('#edit-' + el_id).wymeditor(editor_options);
                 });
                 break;
             case 'redactor':
-                target.find('.front-edit-container').html(html).redactor();
+                target.addClass('front-edit-redactor');
+                var editor_options = $.extend({minHeight:400}, document._front_edit.editor_options);
+                target.find('.front-edit-container').html(html).redactor(editor_options);
                 break;
             case 'epiceditor':
                 $.when(
@@ -90,35 +89,35 @@ jQuery(document).ready(function($) {
                         $(deferred.resolve);
                     })
                 ).done(function(){
-                    var opts = {
-                      container: 'epiceditor',
-                      textarea: null,
-                      basePath: document._front_edit.static_root+'epiceditor',
-                      clientSideStorage: false,
-                      localStorageName: 'epiceditor',
-                      useNativeFullscreen: true,
-                      parser: marked,
-                      file: {
-                        name: 'epiceditor',
-                        defaultContent: toMarkdown(html),
-                        autoSave: 100
-                    },
-                    button: {
-                        preview: true,
-                        fullscreen: true
-                    },
-                    focusOnLoad: false,
-                    shortcut: {
-                        modifier: 18,
-                        fullscreen: 70,
-                        preview: 80
-                    },
-                    string: {
-                        togglePreview: 'Toggle Preview Mode',
-                        toggleEdit: 'Toggle Edit Mode',
-                        toggleFullscreen: 'Enter Fullscreen'
-                    }
-                };
+                    var opts = $.extend({
+                        container: 'epiceditor',
+                        textarea: null,
+                        basePath: document._front_edit.static_root+'epiceditor',
+                        clientSideStorage: false,
+                        localStorageName: 'epiceditor',
+                        useNativeFullscreen: true,
+                        parser: marked,
+                        file: {
+                            name: 'epiceditor',
+                            defaultContent: toMarkdown(html),
+                            autoSave: 100
+                        },
+                        button: {
+                            preview: true,
+                            fullscreen: true
+                        },
+                        focusOnLoad: false,
+                        shortcut: {
+                            modifier: 18,
+                            fullscreen: 70,
+                            preview: 80
+                        },
+                        string: {
+                            togglePreview: 'Toggle Preview Mode',
+                            toggleEdit: 'Toggle Edit Mode',
+                            toggleFullscreen: 'Enter Fullscreen'
+                        }
+                    }, document._front_edit.editor_options);
                 editor = new EpicEditor(opts).load();
             });
 
@@ -173,5 +172,11 @@ jQuery(document).ready(function($) {
             el.html(new_html);
             $('#front-edit-lightbox-container').remove();
         });
+    };
+
+    $('.editable').on('dblclick', function(event) {
+        event.preventDefault();
+        var el = jQuery(this);
+        triggerEditor(el);
     });
 });
